# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import enum

import winrt.system
from winrt._winrt_windows_management_workplace import (
    MdmPolicy,
    WorkplaceSettings,
)

__all__ = [
    "MessagingSyncPolicy",
    "MdmPolicy",
    "WorkplaceSettings",
]

class MessagingSyncPolicy(enum.IntEnum):
    DISALLOWED = 0
    ALLOWED = 1
    REQUIRED = 2




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

from winrt.windows.management.workplace import MessagingSyncPolicy

Self = typing.TypeVar('Self')

@typing.final
class MdmPolicy_Static(winrt._winrt.IInspectable_Static):
    # Windows.Management.Workplace.MessagingSyncPolicy Windows.Management.Workplace.MdmPolicy::GetMessagingSyncPolicy()
    def get_messaging_sync_policy(cls) -> MessagingSyncPolicy: ...
    # System.Boolean Windows.Management.Workplace.MdmPolicy::IsBrowserAllowed()
    def is_browser_allowed(cls) -> bool: ...
    # System.Boolean Windows.Management.Workplace.MdmPolicy::IsCameraAllowed()
    def is_camera_allowed(cls) -> bool: ...
    # System.Boolean Windows.Management.Workplace.MdmPolicy::IsMicrosoftAccountAllowed()
    def is_microsoft_account_allowed(cls) -> bool: ...
    # System.Boolean Windows.Management.Workplace.MdmPolicy::IsStoreAllowed()
    def is_store_allowed(cls) -> bool: ...

@typing.final
class MdmPolicy(winrt.system.Object, metaclass=MdmPolicy_Static):
    pass

@typing.final
class WorkplaceSettings_Static(winrt._winrt.IInspectable_Static):
    # System.Boolean Windows.Management.Workplace.WorkplaceSettings::get_IsMicrosoftAccountOptional()
    @_property
    def is_microsoft_account_optional(cls) -> bool: ...

@typing.final
class WorkplaceSettings(winrt.system.Object, metaclass=WorkplaceSettings_Static):
    pass

